pub trait LedgerService:
Send
+ Sync
+ 'static {
// Provided methods
fn list_checkpoints<'life0, 'async_trait>(
&'life0 self,
request: Request<ListCheckpointsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListCheckpointsResponse>>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn list_transactions<'life0, 'async_trait>(
&'life0 self,
request: Request<ListTransactionsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListTransactionsResponse>>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn list_events<'life0, 'async_trait>(
&'life0 self,
request: Request<ListEventsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListEventsResponse>>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
}Available on crate feature
unstable only.Expand description
Generated trait containing gRPC methods that should be implemented for use with LedgerServiceServer.
Provided Methods
Sourcefn list_checkpoints<'life0, 'async_trait>(
&'life0 self,
request: Request<ListCheckpointsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListCheckpointsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_checkpoints<'life0, 'async_trait>(
&'life0 self,
request: Request<ListCheckpointsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListCheckpointsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List checkpoints matching the provided filters.
Checkpoints are returned in ascending or descending checkpoint sequence number order according to the query options ordering. A checkpoint matches if any transaction it contains satisfies the filter.
Sourcefn list_transactions<'life0, 'async_trait>(
&'life0 self,
request: Request<ListTransactionsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListTransactionsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_transactions<'life0, 'async_trait>(
&'life0 self,
request: Request<ListTransactionsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListTransactionsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List transactions matching the provided filters.
Transactions are returned in ascending or descending transaction sequence order according to the query options ordering.
Sourcefn list_events<'life0, 'async_trait>(
&'life0 self,
request: Request<ListEventsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListEventsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_events<'life0, 'async_trait>(
&'life0 self,
request: Request<ListEventsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<BoxStream<ListEventsResponse>>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List events matching the provided filters.
Events are returned in ascending or descending packed event sequence order according to the query options ordering.